@@ -1,9 +1,10 @@
 /*
-**  Str - String Library
-**  Copyright (c) 1999-2001 Ralf S. Engelschall <rse@engelschall.com>
+**  OSSP str - String Handling
+**  Copyright (c) 1999-2002 Ralf S. Engelschall <rse@engelschall.com>
+**  Copyright (c) 1999-2002 The OSSP Project <http://www.ossp.org/>
 **
-**  This file is part of Str, a string handling and manipulation 
-**  library which can be found at http://www.engelschall.com/sw/str/.
+**  This file is part of OSSP str, a string handling and manipulation 
+**  library which can be found at http://www.ossp.org/pkg/lib/str/.
 **
 **  Permission to use, copy, modify, and distribute this software for
 **  any purpose with or without fee is hereby granted, provided that
@@ -29,13 +30,15 @@
 #ifndef _STR_P_H_
 #define _STR_P_H_
 
-#include "str.h"
-#include "str_config.h"
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
 
 #include <stdlib.h>     /* for malloc, etc. */
 #include <math.h>       /* for modf(3) */
 #include <string.h>     /* ... */
 
+#include "str.h"
 #include "str_pcre.h"
 
 #if defined(HAVE_DMALLOC_H) && defined(WITH_DMALLOC)
